@@ -4,21 +4,22 @@
   rbglib.c -
 
   $Author: mutoh $
-  $Date: 2004/08/18 16:42:35 $
+  $Date: 2005/03/05 06:55:37 $
 
   Copyright (C) 2002,2003  Masahiro Sakai
 
 **********************************************************************/
 
-#include <glib.h>
 #include <locale.h>
 #include "global.h"
+#include "rbglib.h"
 
 VALUE mGLib;
 
 extern void Init_utils_int64();
 extern void Init_gutil();
 extern void Init_glib_error();
+extern void Init_glib_threads();
 extern void Init_glib_convert();
 extern void Init_glib_messages();
 extern void Init_glib_spawn();
@@ -141,6 +142,7 @@ void Init_glib2()
     Init_utils_int64();
     Init_gutil();
     Init_glib_error();
+    Init_glib_threads();
     Init_glib_convert();
     Init_glib_messages();
     Init_glib_spawn();
