@@ -4,7 +4,7 @@
   rbgobj_object.c -
 
   $Author: mutoh $
-  $Date: 2004/08/22 13:26:50 $
+  $Date: 2005/01/29 11:41:17 $
 
   Copyright (C) 2002-2004  Ruby-GNOME2 Project Team
   Copyright (C) 2002-2003  Masahiro Sakai
@@ -240,6 +240,7 @@ gobj_set_property(self, prop_name, val)
         // FIXME: use rb_ensure to call g_value_unset()
         RValueToGValueFunc setter = NULL;
         GValue gval = {0,};
+
         g_value_init(&gval, G_PARAM_SPEC_VALUE_TYPE(pspec));
 
         {
@@ -251,15 +252,15 @@ gobj_set_property(self, prop_name, val)
                     Data_Get_Struct(obj, void, setter);
             }
         }
-
-        if (setter)
+        if (setter) {
             setter(val, &gval);
-        else {
+        } else {
             rbgobj_rvalue_to_gvalue(val, &gval);
         }
 
         g_object_set_property(RVAL2GOBJ(self), name, &gval);
         g_value_unset(&gval);
+
         return self;
     }
 }
@@ -605,7 +606,7 @@ Init_gobject_gobject()
 #ifndef HAVE_RB_DEFINE_ALLOC_FUNC
     rb_define_singleton_method(cGObject, "allocate", &gobj_s_allocate, 0);
 #else
-    rb_define_alloc_func(cGObject, gobj_s_allocate);
+    rb_define_alloc_func(cGObject, (VALUE(*)_((VALUE)))gobj_s_allocate);
 #endif
     rb_define_singleton_method(cGObject, "new!", gobj_s_gobject_new, -1);
 
