@@ -27,6 +27,8 @@ gpui_job_preview_new(VALUE self, VALUE job, VALUE title)
 {
   G_INITIALIZE(self, gnome_print_job_preview_new(RVAL2GOBJ(job),
                                                  RVAL2CSTR(title)));
+  /* XXX: Is it good way??? */
+  g_object_ref(_SELF(self));
   return Qnil;
 }
 
