@@ -3,10 +3,10 @@
 
   rbgdkwindow.c -
 
-  $Author: isambart $
-  $Date: 2004/08/01 17:04:17 $
+  $Author: mutoh $
+  $Date: 2005/02/07 16:56:39 $
 
-  Copyright (C) 2002-2004 Ruby-GNOME2 Project Team
+  Copyright (C) 2002-2005 Ruby-GNOME2 Project Team
   Copyright (C) 1998-2000 Yukihiro Matsumoto,
                           Daisuke Kanda,
                           Hiroshi Igarashi
@@ -373,6 +373,8 @@ invalidate_child_func_wrap(window, func)
     return RTEST(result);
 }
 
+typedef gboolean (*ChildFunc) (GdkWindow*, gpointer);
+
 static VALUE
 gdkwin_invalidate_maybe_recurse(self, region)
     VALUE self, region;
@@ -384,7 +386,7 @@ gdkwin_invalidate_maybe_recurse(self, region)
     }
     gdk_window_invalidate_maybe_recurse(_SELF(self),
                                         RVAL2BOXED(region, GDK_TYPE_REGION),
-                                        invalidate_child_func_wrap,
+                                        (ChildFunc)invalidate_child_func_wrap,
                                         (gpointer)func);
     return self;
 }
@@ -450,6 +452,28 @@ gdkwin_get_internal_paint_info(self)
                        INT2NUM(x_offset), INT2NUM(y_offset));
 }
 
+#if GTK_CHECK_VERSION(2,6,0)
+static VALUE
+gdkwin_configure_finished(self)
+    VALUE self;
+{
+    gdk_window_configure_finished(_SELF(self));
+    return self;
+}
+
+static VALUE
+gdkwin_enable_synchronized_configure(self)
+    VALUE self;
+{
+    gdk_window_enable_synchronized_configure(_SELF(self));
+
+    if (rb_block_given_p()) {
+        rb_ensure(rb_yield, self, gdkwin_configure_finished, self);
+    }
+    return self;
+}
+#endif
+
 static VALUE
 gdkwin_set_user_data(self, user_data)
     VALUE self, user_data;
@@ -477,6 +501,16 @@ gdkwin_set_accept_focus(self, accept_focus)
 }
 #endif
 
+#if GTK_CHECK_VERSION(2,6,0)
+static VALUE
+gdkwin_set_focus_on_map(self, focus_on_map)
+    VALUE self, focus_on_map;
+{
+    gdk_window_set_focus_on_map(_SELF(self), RTEST(focus_on_map));
+    return self;
+}
+#endif
+
 /* GdkXEvent is not implemented.
   void        gdk_window_add_filter           (GdkWindow *window,
   GdkFilterFunc function,
@@ -647,7 +681,7 @@ static VALUE
 gdkwin_set_skip_taskbar_hint(self, hint)
     VALUE self, hint;
 {
-    gdkwin_set_skip_taskbar_hint(_SELF(self), RTEST(hint));
+    gdk_window_set_skip_taskbar_hint(_SELF(self), RTEST(hint));
     return self;
 }
 
@@ -655,7 +689,7 @@ static VALUE
 gdkwin_set_skip_pager_hint(self, hint)
     VALUE self, hint;
 {
-    gdkwin_set_skip_pager_hint(_SELF(self), RTEST(hint));
+    gdk_window_set_skip_pager_hint(_SELF(self), RTEST(hint));
     return self;
 }
 #endif
@@ -884,8 +918,8 @@ gdkwin_foreign_new(argc, argv, self)
 #else
     	win = gdk_window_foreign_new(NUM2UINT(arg[1])); 
         rb_warn("Not supported in GTK+-2.0.x.");
-#endif
-    	break;
+#endif 
+   	break;
     }
     if (win == NULL)
         return Qnil;
@@ -990,10 +1024,17 @@ Init_gtk_gdk_window()
     rb_define_method(gdkWindow, "thaw_updates", gdkwin_thaw_updates, 0);
     rb_define_method(gdkWindow, "process_updates", gdkwin_process_updates, 1);
     rb_define_method(gdkWindow, "internal_paint_info", gdkwin_get_internal_paint_info, 0);
+#if GTK_CHECK_VERSION(2,6,0)
+    rb_define_method(gdkWindow, "configure_finished", gdkwin_configure_finished, 0);
+    rb_define_method(gdkWindow, "enable_synchronized_configure", gdkwin_enable_synchronized_configure, 0);
+#endif
     rb_define_method(gdkWindow, "set_user_data", gdkwin_set_user_data, 1);
     rb_define_method(gdkWindow, "set_override_redirect", gdkwin_set_override_redirect, 1);
 #if GTK_CHECK_VERSION(2,4,0)
     rb_define_method(gdkWindow, "set_accept_focus", gdkwin_set_accept_focus, 1);
+#endif
+#if GTK_CHECK_VERSION(2,6,0)
+    rb_define_method(gdkWindow, "set_focus_on_map", gdkwin_set_focus_on_map, 1);
 #endif
     rb_define_method(gdkWindow, "shape_combine_mask", gdkwin_shape_combine_mask, 3);
     rb_define_method(gdkWindow, "shape_combine_region", gdkwin_shape_combine_region, 3);
