@@ -448,6 +448,78 @@ static VALUE rb_gda_connection_drop_database(self, db)
                                                    RVAL2CSTR(db)));
 }
 
+#if defined(GDA_AT_LEAST_1_1)
+/*
+ * Method: reset!
+ *
+ * Resets the connection.
+ *
+ * Returns: true if successful, false otherwise.
+ */
+static VALUE rb_gda_connection_reset(self)
+    VALUE self;
+{
+    return CBOOL2RVAL(gda_connection_reset(RGDA_CONNECTION(self)));
+}
+
+/*
+ * Method: clear_errors
+ *
+ * This method lets you clear the list of Gda::Error's of the
+ * current connection. This is useful to reuse a Gda::Connection
+ * because next uses of Gda::Connection#errors will return an empty
+ * list.
+ * 
+ * Returns: self.
+ */
+static VALUE rb_gda_connection_clear_errors(self)
+    VALUE self;
+{
+    gda_connection_clear_error_list(RGDA_CONNECTION(self));
+    return self;
+}
+
+/*
+ * Method: create_table(name, attributes)
+ * name: the name of the table to create.
+ * attributes: an array of Gda::FieldAttributes objects.
+ *
+ * Creates a table on the current connection from the given set of fields.
+ *
+ * Returns: true if successful, false otherwise.
+ */
+static VALUE rb_gda_connection_create_table(self, name, attributes)
+    VALUE self, name, attributes;
+{
+    GdaFieldAttributes **c_attributes;
+    int i;
+    gboolean ok;
+    
+    c_attributes = g_new(GdaFieldAttributes *, RARRAY(attributes)->len);
+    for (i = 0; i < RARRAY(attributes)->len; i++)
+        c_attributes[i] = RGDA_FIELD_ATTRIBUTES(rb_ary_entry(attributes, i));
+    ok = gda_connection_create_table(RGDA_CONNECTION(self), RVAL2CSTR(name), 
+                                     (const GdaFieldAttributes **)c_attributes);
+    free(c_attributes);
+
+    return CBOOL2RVAL(attributes);
+}
+
+/*
+ * Method: drop_table(name)
+ * name: the name of the table to drop.
+ *
+ * Drops a table from the database.
+ *
+ * Returns: true if successful, false otherwise.
+ */
+static VALUE rb_gda_connection_drop_table(self, name)
+    VALUE self, name;
+{
+    return CBOOL2RVAL(gda_connection_drop_table(RGDA_CONNECTION(self), RVAL2CSTR(name)));
+}
+#endif /* GDA_AT_LEAST_1_1 */
+
 /*
  * Method: supports?(feature)
  * feature: feature to ask for (see Gda::Connection::Feature).
@@ -527,12 +599,19 @@ void Init_gda_connection(void) {
 
     rb_define_method(c, "errors",     rb_gda_connection_get_errors,  0);
     rb_define_method(c, "add_errors", rb_gda_connection_add_errors, -2);
-
+    
     rb_define_method(c, "database",        rb_gda_connection_get_database,    0);
     rb_define_method(c, "change_database", rb_gda_connection_change_database, 0);
     rb_define_method(c, "create_database", rb_gda_connection_create_database, 0);
     rb_define_method(c, "drop_database",   rb_gda_connection_drop_database,   0);
 
+#if defined(GDA_AT_LEAST_1_1)
+    rb_define_method(c, "reset!",  rb_gda_connection_reset,     0);
+    rb_define_method(c, "clear_errors", rb_gda_connection_clear_errors, 0);
+    rb_define_method(c, "create_table", rb_gda_connection_create_table, 2);
+    rb_define_method(c, "drop_table", rb_gda_connection_drop_table, 1);
+#endif
+    
     rb_define_method(c, "supports?", rb_gda_connection_supports, 1);
 
     rb_define_method(c, "get_schema", rb_gda_connection_get_schema, -1);
